pub struct TextExtractor { /* private fields */ }Expand description
Extracts text characters from a DisplayTree by visiting text nodes.
Implementations
Sourceimpl TextExtractor
impl TextExtractor
Sourcepub fn new() -> TextExtractor
pub fn new() -> TextExtractor
Create a new empty text extractor.
Sourcepub fn with_rtl(rtl: bool) -> TextExtractor
pub fn with_rtl(rtl: bool) -> TextExtractor
Create a new text extractor with an RTL base direction hint.
When rtl is true and the icu feature is enabled, bidi reordering
uses RTL as the default paragraph direction.
Sourcepub fn into_characters(self) -> (Vec<TextCharacter>, Vec<Option<u32>>)
pub fn into_characters(self) -> (Vec<TextCharacter>, Vec<Option<u32>>)
Consume the extractor and return all collected characters with their run IDs.